# Generated by Django 3.2.13 on 2022-07-14 18:36

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0122_auto_20220708_2144"),
    ]

    operations = [
        migrations.AddField(
            model_name="bloodresultsfbc",
            name="missing",
            field=models.TextField(
                editable=False,
                help_text="calculated string of field names that have been left blank",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsfbc",
            name="missing_count",
            field=models.IntegerField(
                default=0, editable=False, help_text="A count of fields left blank"
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsglu",
            name="missing",
            field=models.TextField(
                editable=False,
                help_text="calculated string of field names that have been left blank",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsglu",
            name="missing_count",
            field=models.IntegerField(
                default=0, editable=False, help_text="A count of fields left blank"
            ),
        ),
        migrations.AddField(
            model_name="bloodresultshba1c",
            name="missing",
            field=models.TextField(
                editable=False,
                help_text="calculated string of field names that have been left blank",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="bloodresultshba1c",
            name="missing_count",
            field=models.IntegerField(
                default=0, editable=False, help_text="A count of fields left blank"
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsins",
            name="missing",
            field=models.TextField(
                editable=False,
                help_text="calculated string of field names that have been left blank",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsins",
            name="missing_count",
            field=models.IntegerField(
                default=0, editable=False, help_text="A count of fields left blank"
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslft",
            name="missing",
            field=models.TextField(
                editable=False,
                help_text="calculated string of field names that have been left blank",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslft",
            name="missing_count",
            field=models.IntegerField(
                default=0, editable=False, help_text="A count of fields left blank"
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslipid",
            name="missing",
            field=models.TextField(
                editable=False,
                help_text="calculated string of field names that have been left blank",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslipid",
            name="missing_count",
            field=models.IntegerField(
                default=0, editable=False, help_text="A count of fields left blank"
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsrft",
            name="missing",
            field=models.TextField(
                editable=False,
                help_text="calculated string of field names that have been left blank",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsrft",
            name="missing_count",
            field=models.IntegerField(
                default=0, editable=False, help_text="A count of fields left blank"
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsfbc",
            name="missing",
            field=models.TextField(
                editable=False,
                help_text="calculated string of field names that have been left blank",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsfbc",
            name="missing_count",
            field=models.IntegerField(
                default=0, editable=False, help_text="A count of fields left blank"
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsglu",
            name="missing",
            field=models.TextField(
                editable=False,
                help_text="calculated string of field names that have been left blank",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsglu",
            name="missing_count",
            field=models.IntegerField(
                default=0, editable=False, help_text="A count of fields left blank"
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultshba1c",
            name="missing",
            field=models.TextField(
                editable=False,
                help_text="calculated string of field names that have been left blank",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultshba1c",
            name="missing_count",
            field=models.IntegerField(
                default=0, editable=False, help_text="A count of fields left blank"
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsins",
            name="missing",
            field=models.TextField(
                editable=False,
                help_text="calculated string of field names that have been left blank",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsins",
            name="missing_count",
            field=models.IntegerField(
                default=0, editable=False, help_text="A count of fields left blank"
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslft",
            name="missing",
            field=models.TextField(
                editable=False,
                help_text="calculated string of field names that have been left blank",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslft",
            name="missing_count",
            field=models.IntegerField(
                default=0, editable=False, help_text="A count of fields left blank"
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslipid",
            name="missing",
            field=models.TextField(
                editable=False,
                help_text="calculated string of field names that have been left blank",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslipid",
            name="missing_count",
            field=models.IntegerField(
                default=0, editable=False, help_text="A count of fields left blank"
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsrft",
            name="missing",
            field=models.TextField(
                editable=False,
                help_text="calculated string of field names that have been left blank",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsrft",
            name="missing_count",
            field=models.IntegerField(
                default=0, editable=False, help_text="A count of fields left blank"
            ),
        ),
    ]



from django.conf import settings
from django.contrib.auth.views import LogoutView
from django.urls.conf import include, path, re_path
from django.views.defaults import page_not_found, server_error  # noqa
from django.views.generic import RedirectView
from edc_dashboard.utils import get_index_page
from edc_dashboard.views import AdministrationView
from edc_utils.paths_for_urlpatterns import paths_for_urlpatterns

from .views import HomeView


def trigger_error(request):
    division_by_zero = 1 / 0  # noqa


handler403 = "edc_dashboard.views.edc_handler403"
handler404 = "edc_dashboard.views.edc_handler404"
handler500 = "edc_dashboard.views.edc_handler500"

urlpatterns = [
    path("accounts/", include("edc_auth.urls_for_accounts", namespace="auth")),
    path("administration/", AdministrationView.as_view(), name="administration_url"),
    path("subject/", include("meta_dashboard.urls")),
    *paths_for_urlpatterns("edc_pylabels"),
    *paths_for_urlpatterns("edc_auth"),
    *paths_for_urlpatterns("edc_action_item"),
    *paths_for_urlpatterns("edc_adverse_event"),
    *paths_for_urlpatterns("edc_appointment"),
    *paths_for_urlpatterns("edc_consent"),
    *paths_for_urlpatterns("edc_crf"),
    *paths_for_urlpatterns("edc_dashboard"),
    *paths_for_urlpatterns("edc_data_manager"),
    *paths_for_urlpatterns("edc_device"),
    *paths_for_urlpatterns("edc_export"),
    *paths_for_urlpatterns("edc_facility"),
    *paths_for_urlpatterns("edc_form_runners"),
    *paths_for_urlpatterns("edc_identifier"),
    *paths_for_urlpatterns("edc_lab"),
    *paths_for_urlpatterns("edc_lab_dashboard"),
    *paths_for_urlpatterns("edc_label"),
    *paths_for_urlpatterns("edc_locator"),
    *paths_for_urlpatterns("edc_metadata"),
    *paths_for_urlpatterns("edc_mnsi"),
    *paths_for_urlpatterns("edc_notification"),
    *paths_for_urlpatterns("edc_offstudy"),
    *paths_for_urlpatterns("edc_pdf_reports"),
    *paths_for_urlpatterns("edc_pdutils"),
    *paths_for_urlpatterns("edc_pharmacy"),
    *paths_for_urlpatterns("edc_protocol"),
    *paths_for_urlpatterns("edc_protocol_incident"),
    *paths_for_urlpatterns("edc_qol"),
    *paths_for_urlpatterns("edc_randomization"),
    *paths_for_urlpatterns("edc_reportable"),
    *paths_for_urlpatterns("edc_refusal"),
    *paths_for_urlpatterns("edc_registration"),
    *paths_for_urlpatterns("edc_review_dashboard"),
    *paths_for_urlpatterns("edc_sites"),
    *paths_for_urlpatterns("edc_subject_dashboard"),
    *paths_for_urlpatterns("edc_unblinding"),
    *paths_for_urlpatterns("edc_qareports"),
    *paths_for_urlpatterns("edc_visit_schedule"),
    *paths_for_urlpatterns("meta_ae"),
    *paths_for_urlpatterns("meta_consent"),
    *paths_for_urlpatterns("meta_export"),
    *paths_for_urlpatterns("meta_lists"),
    *paths_for_urlpatterns("meta_pharmacy"),
    *paths_for_urlpatterns("meta_prn"),
    *paths_for_urlpatterns("meta_screening"),
    *paths_for_urlpatterns("meta_subject"),
    *paths_for_urlpatterns("meta_reports"),
]

if settings.DEFENDER_ENABLED:
    urlpatterns.append(
        path("defender/", include("defender.urls")),  # defender admin
    )

urlpatterns += [
    # path("__debug__/", include("debug_toolbar.urls")),
    path("admin/", RedirectView.as_view(url="/")),
    path(
        "switch_sites/",
        LogoutView.as_view(next_page=get_index_page()),
        name="switch_sites_url",
    ),
    path("home/", HomeView.as_view(), name="home_url"),
    path("i18n/", include("django.conf.urls.i18n")),
    re_path(".", RedirectView.as_view(url="/"), name="home_url"),
    re_path("", HomeView.as_view(), name="home_url"),
]



# Generated by Django 5.0 on 2024-01-09 23:21

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_lists", "0015_abnormalfootappearanceobservations_extra_value_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="abnormalfootappearanceobservations",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Abnormal Foot Appearance Observations",
                "verbose_name_plural": "Abnormal Foot Appearance Observations",
            },
        ),
        migrations.AlterModelOptions(
            name="arvregimens",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "ARV Regimens",
                "verbose_name_plural": "ARV Regimens",
            },
        ),
        migrations.AlterModelOptions(
            name="baselinesymptoms",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Baseline Symptoms",
                "verbose_name_plural": "Baseline Symptoms",
            },
        ),
        migrations.AlterModelOptions(
            name="diabetessymptoms",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Diabetes Symptoms",
                "verbose_name_plural": "Diabetes Symptoms",
            },
        ),
        migrations.AlterModelOptions(
            name="hypertensionmedications",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Hypertension Medications",
                "verbose_name_plural": "Hypertension Medications",
            },
        ),
        migrations.AlterModelOptions(
            name="nonadherencereasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Non-Adherence Reasons",
                "verbose_name_plural": "Non-Adherence Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="offstudyreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Offstudy Reasons",
                "verbose_name_plural": "Offstudy Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="oiprophylaxis",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "OI Prophylaxis",
                "verbose_name_plural": "OI Prophylaxis",
            },
        ),
        migrations.AlterModelOptions(
            name="subjectvisitmissedreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Subject Missed Visit Reasons",
                "verbose_name_plural": "Subject Missed Visit Reasons",
            },
        ),
        migrations.AlterModelOptions(
            name="symptoms",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Symptoms",
                "verbose_name_plural": "Symptoms",
            },
        ),
        migrations.AlterModelOptions(
            name="transferreasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Transfer Reasons",
                "verbose_name_plural": "Transfer Reasons",
            },
        ),
        migrations.RemoveIndex(
            model_name="abnormalfootappearanceobservations",
            name="meta_lists__id_4c71ac_idx",
        ),
        migrations.RemoveIndex(
            model_name="arvregimens",
            name="meta_lists__id_18210c_idx",
        ),
        migrations.RemoveIndex(
            model_name="baselinesymptoms",
            name="meta_lists__id_5cfb01_idx",
        ),
        migrations.RemoveIndex(
            model_name="diabetessymptoms",
            name="meta_lists__id_9b6cbb_idx",
        ),
        migrations.RemoveIndex(
            model_name="hypertensionmedications",
            name="meta_lists__id_50f1f2_idx",
        ),
        migrations.RemoveIndex(
            model_name="nonadherencereasons",
            name="meta_lists__id_5a7907_idx",
        ),
        migrations.RemoveIndex(
            model_name="offstudyreasons",
            name="meta_lists__id_713d23_idx",
        ),
        migrations.RemoveIndex(
            model_name="oiprophylaxis",
            name="meta_lists__id_399299_idx",
        ),
        migrations.RemoveIndex(
            model_name="subjectvisitmissedreasons",
            name="meta_lists__id_4ee3a4_idx",
        ),
        migrations.RemoveIndex(
            model_name="symptoms",
            name="meta_lists__id_1f5296_idx",
        ),
        migrations.RemoveIndex(
            model_name="transferreasons",
            name="meta_lists__id_77e6e7_idx",
        ),
        migrations.AlterField(
            model_name="abnormalfootappearanceobservations",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="abnormalfootappearanceobservations",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="abnormalfootappearanceobservations",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="arvregimens",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="arvregimens",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="arvregimens",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="baselinesymptoms",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="baselinesymptoms",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="baselinesymptoms",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="diabetessymptoms",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="diabetessymptoms",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="diabetessymptoms",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="hypertensionmedications",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="hypertensionmedications",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="hypertensionmedications",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="nonadherencereasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="nonadherencereasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="nonadherencereasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="offstudyreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="offstudyreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="offstudyreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="oiprophylaxis",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="oiprophylaxis",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="oiprophylaxis",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissedreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissedreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissedreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="symptoms",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="symptoms",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="symptoms",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AlterField(
            model_name="transferreasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="transferreasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="transferreasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AddIndex(
            model_name="abnormalfootappearanceobservations",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="meta_lists__display_51dd8e_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="arvregimens",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="meta_lists__display_cb3dab_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="baselinesymptoms",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="meta_lists__display_50ad46_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="diabetessymptoms",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="meta_lists__display_972b49_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="hypertensionmedications",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="meta_lists__display_8e7e18_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="nonadherencereasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="meta_lists__display_9df6c9_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offstudyreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="meta_lists__display_8f992e_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="oiprophylaxis",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="meta_lists__display_cb099e_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjectvisitmissedreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="meta_lists__display_ed4ee5_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="symptoms",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="meta_lists__display_a89780_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="transferreasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="meta_lists__display_73715d_idx",
            ),
        ),
    ]
